==> md-resume-0.2.2.tar.gz: md-resume-0.2.2/README.md <==
# yiwen song

[![Build Status](https://travis-ci.org/yiwensong/resume.svg?branch=master)](https://travis-ci.org/yiwensong/resume)
[![Coverage Status](https://coveralls.io/repos/github/yiwensong/resume/badge.svg?branch=master)](https://coveralls.io/github/yiwensong/resume?branch=master)
[![PyPI version](https://badge.fury.io/py/md-resume.svg)](https://badge.fury.io/py/md-resume)

[Personal Site](http://yiwensong.com) |
[Email](mailto:songzgy@gmail.com)

---
## Education
### University of California, Berkeley - June 2016

Computer Science, B.A.  
Major GPA: 3.739  

---
## Work Experience
### Deploy Team at Stripe (Apr 2019 - Present)
*San Francisco, CA*

* Lead the unattended deployments project for safely automating service deployments.
* Improved canarying and added automated reliability features by integrating with our health evaluation service.
* Designed improvments to the deployment web frontend to be more clear and user-friendly.

### Release Engineering at Yelp (Nov 2017 - Apr 2019)
*San Francisco, CA*

* Worked on an internal frontend service that tracks and displays tech debt and developer prductivity.
* Designed and implemented API for determining responsibility and ownership of code, databases, and other resources.
* Improved Git management tools and code review infrastructure to be more resilient to catastrophic failures.

### Trading and Data at Old Mission Capital (Aug 2016 - May 2017)
*Chicago, IL*

* Improved data pipeline and research infrastructure reliability and usability.
* Added parallelism to data ingestion and created automated sanity checking to reduce overhead of analysis.
* Developed a Python package for quickly scripting models and risk calculation on live market data.

### Trading Intern at Old Mission Capital (Jun 2015 - Aug 2015)

---
## Projects
### [GPU Compression](https://github.com/yiwensong/lzss)

* Parallelized implementation of LZSS compression for the GPU with CUDA.
* The goal of the project was to test feasibility of using message compression in HPC applications.
* Result: your network needs to be *really* bad for this to be worth anything.

### [ImgCompress](https://github.com/yiwensong/imgcompress)

* ImgCompress is a hackathon project aimed at becoming the future of compression.
* Uploads binaries to Imgur as PNGs and stores the 7 character Imgur URL.
* Compression ratio is over 700 000 and implementation is less than 200 lines of python.
* Better than the CUDA stuff I made.

### [Poker AI](https://github.com/yiwensong/huplo)

* Heads Up Pot-Limit Omaha (HUPLO) AI that uses Monte Carlo search trees and bad machine learning.
* 💩 at poker.
* Passable at Tic-Tac-Toe.

### [Yet Another Personal Site | DefDontHire.Me](https://github.com/yiwensong/yiwensong.github.io)

* Technology has advanced to a point where you can create a beautiful website without knowing any web.
* Literally anyone can download a Bootstrap template and write some BS and call it a personal site.
* [Exhibit A](http://yiwensong.com)

### [yiwen.date](https://github.com/yiwensong/yiwen.date)

* Another personal site, but maybe a little more personal.
* Frontend written in React, backend written with Flask.
* [Please do not attempt to date potential future employees.](https://yiwen.date)

---
## SEO
**Interests**: Change management, system reliability, developer productivity tooling  
**Languages**: Python, React (which is Javascript, I guess), Golang, Psuedocode, fish, Mandarin  
**Skills**: INDEX-MATCH fiend, Vim Connoiseur, Nash Equilibrium Hobbyist, "sudo rm -rf /" Frequent User  
**Intangibles**: Clicks buttons really fast, reads the manual  
<div style="font-size:0.2em">
**Literally just SEO terms that vaguely relate to my work**:
Cloud computing, devops, dev-ops, design, software engineering,
software developer, infrastructure, SRE, reliability engineering, docker,
containers, kuberenetes, AWS, amazon web services, s3, EC2,
google cloud platform, gcp, puppet, terraform, services, continous deployment,
continuous integration, CI, CD, CI/CD, Jenkins, build, test execution,
test infrastructure, developer tooling, tox, make, bazel, UI, UX,
web developer, web development, web dev, SaaS, PaaS, backend,
development to production, DNS, load balancer, Travis, Chef, postgres, mysql,
mongodb, database management, migrations
</div>

==> md-resume-0.2.5.tar.gz: md-resume-0.2.5/README.md <==
# yiwen song

[![Build Status](https://travis-ci.org/yiwensong/resume.svg?branch=master)](https://travis-ci.org/yiwensong/resume)
[![Coverage Status](https://coveralls.io/repos/github/yiwensong/resume/badge.svg?branch=master)](https://coveralls.io/github/yiwensong/resume?branch=master)
[![PyPI version](https://badge.fury.io/py/md-resume.svg)](https://badge.fury.io/py/md-resume)

[Personal Site](http://yiwensong.com) |
[Email](mailto:songzgy@gmail.com)

---
## Work Experience
### Deploy Team at Stripe (Apr 2019 - Present)
*San Francisco, CA (and partially remote)*

* Lead the project for implementing automated deployment health evaluation for our deployment system.
* Contributed to creating blue/green deployments to improve the company's services' reliability and fault tolerance story.
* Designed improvments to the deployment web frontend (internal developer-facing) to be more clear and user-friendly.
* Holds the (unofficial) team record for most robot tickets cleared in a week (a major contributor to the team's debt and toil).

### Release Engineering at Yelp (Nov 2017 - Apr 2019)
*San Francisco, CA*

* Worked on an internal frontend service that tracks and displays tech debt and developer prductivity.
* Designed and implemented API for determining responsibility and ownership of code, databases, and other resources.
* Improved Git management tools and code review infrastructure to be more resilient to catastrophic failures.

### Trading and Data at Old Mission Capital (Aug 2016 - May 2017)
*Chicago, IL*

* Improved data pipeline and research infrastructure reliability and usability.
* Added parallelism to data ingestion and created automated sanity checking to reduce overhead of analysis.
* Developed a Python package for quickly scripting models and risk calculation on live market data.

### Trading Intern at Old Mission Capital (Jun 2015 - Aug 2015)

---
## Education
### University of California, Berkeley - June 2016

Computer Science, B.A.  
Major GPA: 3.739  

---
## Projects
### [GPU Compression](https://github.com/yiwensong/lzss)

* Parallelized implementation of LZSS compression for the GPU with CUDA.
* The goal of the project was to test feasibility of using message compression in HPC applications.
* Result: your network needs to be *really* bad for this to be worth anything.

### [ImgCompress](https://github.com/yiwensong/imgcompress)

* ImgCompress is a hackathon project aimed at becoming the future of compression.
* Uploads binaries to Imgur as PNGs and stores the 7 character Imgur URL.
* Compression ratio is over 700 000 and implementation is less than 200 lines of python.
* Better than the CUDA stuff I made.

### [Poker AI](https://github.com/yiwensong/huplo)

* Heads Up Pot-Limit Omaha (HUPLO) AI that uses Monte Carlo search trees and bad machine learning.
* 💩 at poker.
* Passable at Tic-Tac-Toe.

### [Yet Another Personal Site | DefDontHire.Me](https://github.com/yiwensong/yiwensong.github.io)

* Technology has advanced to a point where you can create a beautiful website without knowing any web.
* Literally anyone can download a Bootstrap template and write some BS and call it a personal site.
* [Exhibit A](http://yiwensong.com)

### [yiwen.date](https://github.com/yiwensong/yiwen.date)

* Another personal site, but maybe a little more personal.
* Frontend written in React, backend written with Flask.
* [Please do not attempt to date potential future employees.](https://yiwen.date)

---
## SEO
**Interests**: Change management, system reliability, developer productivity tooling  
**Languages**: Python, React (which is Javascript, I guess), Golang, Psuedocode, fish, Mandarin  
**Skills**: INDEX-MATCH fiend, Vim Connoiseur, Nash Equilibrium Hobbyist, "sudo rm -rf /" Frequent User  
**Intangibles**: Clicks buttons really fast, reads the manual  
**Literally just SEO terms that vaguely relate to my work**:
Cloud computing, devops, dev-ops, design, software engineering,
software developer, infrastructure, SRE, reliability engineering, docker,
containers, kuberenetes, AWS, amazon web services, s3, EC2,
google cloud platform, gcp, puppet, terraform, services, continous deployment,
continuous integration, CI, CD, CI/CD, Jenkins, build, test execution,
test infrastructure, developer tooling, tox, make, bazel, UI, UX,
web developer, web development, web dev, SaaS, PaaS, backend,
development to production, DNS, load balancer, Travis, Chef, postgres, mysql,
mongodb, database management, migrations
